pub struct CustomBlockConfig {
pub class_overrides: HashMap<CustomBlockType, String>,
pub title_overrides: HashMap<CustomBlockType, String>,
}Expand description
Configuration for custom block rendering.
Allows overriding the default CSS class and title for each block type, enabling use with CSS frameworks other than Bootstrap.
Fields
class_overrides: HashMap<CustomBlockType, String>Override the CSS alert class per block type.
title_overrides: HashMap<CustomBlockType, String>Override the display title per block type.
Implementations
Sourceimpl CustomBlockConfig
impl CustomBlockConfig
Sourcepub fn with_class(
self,
block_type: CustomBlockType,
class: impl Into<String>,
) -> Self
pub fn with_class( self, block_type: CustomBlockType, class: impl Into<String>, ) -> Self
Overrides the CSS class for a specific block type.
Sourcepub fn with_title(
self,
block_type: CustomBlockType,
title: impl Into<String>,
) -> Self
pub fn with_title( self, block_type: CustomBlockType, title: impl Into<String>, ) -> Self
Overrides the display title for a specific block type.